.. _ecad api:

:py:mod:`icclim.ecad`
=====================

.. py:module:: icclim.ecad

.. autoapi-nested-parse::

   European Climate Assesment & Dataset (ECAD) indices.

   The ECAD indices public API, via `icclim.ecad` package, is generated from the
   `icclim.ecad.registry.EcadIndexRegistry` registry definitions.
   The parameters of the functions are specialized to each index but are all taken from
   `icclim.main.index` general function.
   In other words, the ECAD indices in `icclim.ecad` package are specializations
   of `icclim.main.index` for ECAD indices.



Submodules
----------
.. toctree::
   :titlesonly:
   :maxdepth: 1

   binding/index.rst
   registry/index.rst


Package Contents
----------------


.. automodule:: icclim._generated._ecad
   :members:

   .. autosummary::
    :nosignatures:

    .. Documentation below is auto-generated with the extract-icclim-funs.py script
    .. Generated API comment:Begin
    tg
    tn
    tx
    dtr
    etr
    vdtr
    su
    tr
    wsdi
    tg90p
    tn90p
    tx90p
    txx
    tnx
    csu
    gd4
    fd
    cfd
    hd17
    id
    tg10p
    tn10p
    tx10p
    txn
    tnn
    csdi
    cdd
    prcptot
    rr1
    sdii
    cwd
    rr
    r10mm
    r20mm
    rx1day
    rx5day
    r75p
    r75ptot
    r95p
    r95ptot
    r99p
    r99ptot
    sd
    sd1
    sd5cm
    sd50cm
    cd
    cw
    wd
    ww
    fxx
    fg6bft
    fgcalm
    fg
    ddnorth
    ddeast
    ddsouth
    ddwest
    gsl
    spi6
    spi3
    pp
    ss
    rh

.. Generated API comment:End
